# PaperMC Updater

**This project is under active development! Features may change or be removed at any time! Not for production usage!**

Thanks to PaperMC for their minecraft server software.

This simple script can manage and update PaperMC servers and minecraft plugins.

This script only works on GNU/Linux, and possibly mac.

For installation and usage instructions, please visit the [docs](https://papermc-updater.readthedocs.io/en/latest/).

Thanks to PaperMC for their minecraft server software.